local _G = _G
module(...)
simple_at_least = {
	name = "Simple At least",
	tag = "synergy_group",
	order = 3,
	description = "Specify number or percent of services you need to be OK. Returns OK or WARNING.",
	hint = "At least count elements from group must be OK",
	rule = function(items, count, unit)
		local c_ok = 0
		local c_wr = 0
		local c_cr = 0
		local c_un = 0
		local res_st = 2
		local res_msg = "Require %s OK(s), got: %s OK(s), %s WARNING(s), %s CRITICAL(s), %s UNKNOWN(s)"
		local n = 0
		for i,value in _G.ipairs(items) do
			if value.status == 0 then c_ok = c_ok + 1
			elseif value.status == 1 then c_wr = c_wr + 1
			elseif value.status == 2 then c_cr = c_cr + 1
			else c_un = c_un + 1
			end
			n = n + 1
		end
		if n == 0 then return {{ status = 3, msg = "No state, default state UNKNOWN" }} end
		if unit == "%" then
			local P_ok, P_wr, P_cr, P_un
			P_ok =_G.math.ceil(100*c_ok/n)
			P_wr =_G.math.ceil(100*c_wr/n)
			P_cr =_G.math.ceil(100*c_cr/n)
			P_un =_G.math.ceil(100*c_un/n)
			res_msg = _G.string.format(res_msg, count.."%", P_ok.."%", P_wr.."%", P_cr.."%", P_un.."%")
			if P_ok >= count then res_st = 0
			elseif P_cr == 0 then res_st = 1
			end
		else
			if n < count then return {{ status = 2, msg = "Not enough subelements to be OK, defined - state CRITICAL" }} end
			if c_ok >= count then res_st = 0
			elseif c_cr == 0 then res_st = 1
			end
			res_msg = _G.string.format(res_msg, count, c_ok, c_wr, c_cr, c_un)
		end
		return {{ status = res_st, msg = res_msg }}
	end,
	params = {
		{
			validation = {
				required = true,
				number = true,
				percent = true,
				min = { 0 }
			},
			name = "count",
			label = "Count",
			type = "number",
			hint = "Count of working services"
		},
		{
			validation = {
				required = true
			},
			name = "unit",
			label = "Unit",
			type = "enum",
			hint = "Unit for the above value (percentage or actual number)",
			values = {"%", "num"}
		}
	}
}
